# discord-lib 0.0.5

discord-lib currently supports discord bots written in JSON, XML and yaml. It will soon support toml, etc

## Installation

```
pip install git+https://github.com/CodeWithSwastik/discord-lib
```
